function Loads=createLoadings(I,J,K,R,structure,choix)
% Loads=createLoadingMatrices(I,J,K,R,structure,choix)
% Creates 3 random loading matrices, where Loads{3} is structured.
% Loads{3} has the following structure:
%   structure=1: Hankel 
%   structure=2: Toeplitz 
%   structure=3: circulant Toeplitz 
%   choix=0: real 
%   choix=1: complex
% Loads{2} is free, and Loads{1} is normalized (because of a scale
% indeterminacy): its 1st row is one if Loads{3} is Hankel, its main
% diagonal is ones if Loads{3} is Toeplitz.
% 
% P.Comon, September 2009, revised July 2014
if nargin<4, I=5;J=4;K=3;R=2;fprintf('Warning: missing arguments. Hence (I,J,K,R) set to (5,4,3,2)\n');end;
if nargin<5, structure=1;end; %  Hankel by default
if nargin<6, choix=0; end; % real by default;
if choix~=0, choix=1;end;ii=sqrt(-1)*choix;
if structure==1,  fprintf('Third loading is a Hankel matrix with ');
    A=[ones(1,R);randn(I-1,R)+ii*randn(I-1,R)];B=randn(J,R)+ii*randn(J,R);
    C=hankel([randn(K-1,1)+ii*randn(K-1,1); 1],[1 randn(1,R-1)+ii*randn(1,R-1)]);
elseif structure==2, fprintf('Third loading is a Toeplitz matrix with '); 
    A=randn(I,R)+ii*randn(I,R);A=A*diag(1./diag(A));
    B=randn(J,R)+ii*randn(J,R);
    C=toeplitz([1;randn(K-1,1)],[1 randn(1,R-1)])+ii*toeplitz([0;randn(K-1,1)],[0 randn(1,R-1)]);
elseif structure==3, 
    if K<=R,fprintf('warning: one must choose R<K in the circulant Toeplitz case\n');end;
    fprintf('Third loading is a circulant Toeplitz matrix with ');
    g=[1;randn(K-1,1)]+ii*[0;randn(K-1,1)];
    C=toeplitz(g,[g(1),g(K:-1:K-R+2).'])+ii*toeplitz([0;g(2:K)],[0,g(K:-1:K-R+2).'])
    A=randn(I,R)+ii*randn(I,R);A=A*diag(1./diag(A));
    B=randn(J,R)+ii*randn(J,R);
end;
if choix==0, fprintf('real values\n');else fprintf('complex values\n');end;

Loads=cell(1,3);Loads{1}=A;Loads{2}=B;Loads{3}=C;